'''iterate print item in nested list which in another list'''

def recurseList(srcList,indent):
        for item in srcList:
                if isinstance(item,list):
                        recurseList(item,indent+1)
                else:
                        for i in range(indent):
                                print('\t',end='')
                        print(item)



from distutils.core import setup

setup(
    name = 'recurseList',
    version = '1.1.2',
    py_modules = ['recurseList'],
    author = 'Jacky',
    author_email = 'pheonix_jk@hotmail.com',
    url = 'http://www.baidu.com',
    description = 'simple printer of nested lists')
